# Organization

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**instance_url** | **str** |  | [optional] 
**domain** | **str** |  | [optional] 
**model_population** | [**ModelPopulation**](ModelPopulation.md) |  | [optional] 
**datasets** | [**list[Dataset]**](Dataset.md) |  | [optional] 
**projects** | [**list[Project]**](Project.md) |  | [optional] 
**organization_settings** | [**list[OrganizationSetting]**](OrganizationSetting.md) |  | [optional] 
**organization_feature_exclusions** | [**list[OrganizationFeatureExclusion]**](OrganizationFeatureExclusion.md) |  | [optional] 
**organization_feature_category_exclusions** | [**list[OrganizationFeatureCategoryExclusion]**](OrganizationFeatureCategoryExclusion.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**databases** | [**list[Database]**](Database.md) |  | [optional] 
**data_queries** | [**list[DataQuery]**](DataQuery.md) |  | [optional] 
**schedulers** | [**list[Scheduler]**](Scheduler.md) |  | [optional] 
**workflows** | [**list[Workflow]**](Workflow.md) |  | [optional] 
**workflow_templates** | [**list[WorkflowTemplate]**](WorkflowTemplate.md) |  | [optional] 
**workflow_executions** | [**list[WorkflowExecution]**](WorkflowExecution.md) |  | [optional] 
**data_store** | [**list[DataStore]**](DataStore.md) |  | [optional] 
**feature_store** | [**list[FeatureStore]**](FeatureStore.md) |  | [optional] 
**population_store** | [**list[PopulationStore]**](PopulationStore.md) |  | [optional] 
**populations** | [**list[Population]**](Population.md) |  | [optional] 
**tasks** | [**list[Task]**](Task.md) |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

